@@ -80,17 +80,20 @@ class Recommendation:
     def recommend(self):
 
         reviews = pd.read_csv(self.reviews_path)
+
+        # adapted from https://www.kaggle.com/thiagopanini/e-commerce-sentiment-analysis-eda-viz-nlp
+
         ## 1. DATA PREVIEW
 
         reviews = reviews.sort_values(by='review_answer_timestamp')
-        reviews.to_csv('revtest.csv')
+        #reviews.to_csv('revtest.csv')
         df_comments = reviews.loc[:, ['review_score', 'review_comment_message']]
         df_comments = df_comments.iloc[99332:, :]
         df_comments = df_comments.dropna(subset=['review_comment_message'])
         df_comments = df_comments.reset_index(drop=True)
         # print(f'Dataset shape: {df_comments.shape}')
         df_comments.columns = ['score', 'comment']
-        df_comments.to_csv('revtest2.csv')
+        #df_comments.to_csv('revtest2.csv')
 
         # print(df_comments.head())
 
@@ -101,186 +104,98 @@ class Recommendation:
         # Breakline and carriage returns
 
         def re_breakline(text_list):
-            """
-            Args:
-            ----------
-            text_list: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             return [re.sub('[\n\r]', ' ', r) for r in text_list]
 
         # Creating a list of comment reviews
         reviews = list(df_comments['comment'].values)
 
-        # Applying RegEx
         reviews_breakline = re_breakline(reviews)
         df_comments['re_breakline'] = reviews_breakline
 
         ## 3. SITES AND HYPERLINKS
 
         def re_hyperlinks(text_list):
-            """
-            Args:
-            ----------
-            text_list: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             pattern = 'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
             return [re.sub(pattern, ' link ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_hyperlinks = re_hyperlinks(reviews_breakline)
         df_comments['re_hyperlinks'] = reviews_hyperlinks
 
         ## 4. DATES
 
         def re_dates(text_list):
-            """
-            Args:
-            ----------
-            text_list: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             pattern = '([0-2][0-9]|(3)[0-1])(\/|\.)(((0)[0-9])|((1)[0-2]))(\/|\.)\d{2,4}'
             return [re.sub(pattern, ' data ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_dates = re_dates(reviews_hyperlinks)
         df_comments['re_dates'] = reviews_dates
 
         ## 5. MONEY
 
         def re_money(text_list):
-            """
-            Args:
-            ----------
-            text_list: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             pattern = '[R]{0,1}\$[ ]{0,}\d+(,|\.)\d+'
             return [re.sub(pattern, ' dinheiro ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_money = re_money(reviews_dates)
         df_comments['re_money'] = reviews_money
 
         ## 6. NUMBERS
 
         def re_numbers(text_list):
-            """
-            Args:
-            ----------
-            text_series: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             return [re.sub('[0-9]+', ' numero ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_numbers = re_numbers(reviews_money)
         df_comments['re_numbers'] = reviews_numbers
 
         ## 7. NEGATION
 
         def re_negation(text_list):
-            """
-            Args:
-            ----------
-            text_series: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             return [re.sub('([nN][ãÃaA][oO]|[ñÑ]| [nN] )', ' negação ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_negation = re_negation(reviews_numbers)
         df_comments['re_negation'] = reviews_negation
 
         ## 8. SPECIAL CHARACTERS
 
         def re_special_chars(text_list):
-            """
-            Args:
-            ----------
-            text_series: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             return [re.sub('\W', ' ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_special_chars = re_special_chars(reviews_negation)
         df_comments['re_special_chars'] = reviews_special_chars
 
         ## 9. WHITESPACES
 
         def re_whitespaces(text_list):
-            """
-            Args:
-            ----------
-            text_series: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             white_spaces = [re.sub('\s+', ' ', r) for r in text_list]
             white_spaces_end = [re.sub('[ \t]+$', '', r) for r in white_spaces]
             return white_spaces_end
 
-        # Applying RegEx
         reviews_whitespaces = re_whitespaces(reviews_special_chars)
         df_comments['re_whitespaces'] = reviews_whitespaces
 
         ## 10. NEGATION
 
         def re_negation(text_list):
-            """
-            Args:
-            ----------
-            text_series: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             return [re.sub('([nN][ãÃaA][oO]|[ñÑ]| [nN] )', ' negação ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_negation = re_negation(reviews_numbers)
         df_comments['re_negation'] = reviews_negation
 
         ## 11. SPECIAL CHARACTERS
 
         def re_special_chars(text_list):
-            """
-            Args:
-            ----------
-            text_series: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             return [re.sub('\W', ' ', r) for r in text_list]
 
-        # Applying RegEx
         reviews_special_chars = re_special_chars(reviews_negation)
         df_comments['re_special_chars'] = reviews_special_chars
 
         ## 12. ADDITIONAL WHITESPACES
 
         def re_whitespaces(text_list):
-            """
-            Args:
-            ----------
-            text_series: list object with text content to be prepared [type: list]
-            """
-
-            # Applying regex
             white_spaces = [re.sub('\s+', ' ', r) for r in text_list]
             white_spaces_end = [re.sub('[ \t]+$', '', r) for r in white_spaces]
             return white_spaces_end
 
-        # Applying RegEx
         reviews_whitespaces = re_whitespaces(reviews_special_chars)
         df_comments['re_whitespaces'] = reviews_whitespaces
 
@@ -290,13 +205,6 @@ class Recommendation:
 
         # Defining a function to remove the stopwords and to lower the comments
         def stopwords_removal(text, cached_stopwords=stopwords.words('portuguese')):
-            """
-            Args:
-            ----------
-            text: list object where the stopwords will be removed [type: list]
-            cached_stopwords: stopwords to be applied on the process [type: list, default: stopwords.words('portuguese')]
-            """
-
             return [c.lower() for c in text.split() if c.lower() not in cached_stopwords]
 
         # Removing stopwords and looking at some examples
@@ -306,13 +214,6 @@ class Recommendation:
         ## 14. STEMMING
 
         def stemming_process(text, stemmer=RSLPStemmer()):
-            """
-            Args:
-            ----------
-            text: list object where the stopwords will be removed [type: list]
-            stemmer: type of stemmer to be applied [type: class, default: RSLPStemmer()]
-            """
-
             return [stemmer.stem(c) for c in text.split()]
 
         # Applying stemming and looking at some examples
@@ -322,12 +223,6 @@ class Recommendation:
         # Feature Extraction
 
         def extract_features_from_corpus(corpus, vectorizer, df=False):
-            """
-            Args
-            ------------
-            text: text to be transformed into a document-term matrix [type: string]
-            vectorizer: engine to be used in the transformation [type: object]
-            """
 
             # Extracting features
             corpus_features = vectorizer.fit_transform(corpus).toarray()
@@ -356,10 +251,6 @@ class Recommendation:
         # Extracting features for the corpus
         tfidf_features, df_tfidf_features = extract_features_from_corpus(reviews_stemmer, tfidf_vectorizer, df=True)
 
-        # Labelling Data
-        ##fig, ax = plt.subplots(figsize=(10, 5))
-        ##single_countplot(x='score', df=df_comments, ax=ax)
-
         # Scores of 1-3 will be considered negative and scores of 4-5 will be considered positive
 
         # Labelling data
@@ -372,20 +263,7 @@ class Recommendation:
         }
         df_comments['sentiment_label'] = df_comments['score'].map(score_map)
 
-        # Verifying results
-        ##fig, ax = plt.subplots(figsize=(7, 7))
-        ##donut_plot(df_comments.query('sentiment_label in ("positive", "negative")'), 'sentiment_label',
-        ##           label_names=df_comments.query('sentiment_label in ("positive", "negative")')['sentiment_label'].value_counts().index,
-        ##           ax=ax, colors=['darkslateblue', 'crimson'])
-
         def ngrams_count(corpus, ngram_range, n=-1, cached_stopwords=stopwords.words('portuguese')):
-            """
-            Args
-            ----------
-            corpus: text to be analysed [type: pd.DataFrame]
-            ngram_range: type of n gram to be used on analysis [type: tuple]
-            n: top limit of ngrams to be shown [type: int, default: -1]
-            """
 
             # Using CountVectorizer to build a bag of words using the given corpus
             vectorizer = CountVectorizer(stop_words=cached_stopwords, ngram_range=ngram_range).fit(corpus)
@@ -407,11 +285,11 @@ class Recommendation:
         unigrams_pos = ngrams_count(positive_comments, (1, 1), 10)
         unigrams_neg = ngrams_count(negative_comments, (1, 1), 10)
 
-        # Extracting the top 10 unigrams by sentiment
+        # Extracting the top 10 bigrams by sentiment
         bigrams_pos = ngrams_count(positive_comments, (2, 2), 10)
         bigrams_neg = ngrams_count(negative_comments, (2, 2), 10)
 
-        # Extracting the top 10 unigrams by sentiment
+        # Extracting the top 10 trigrams by sentiment
         trigrams_pos = ngrams_count(positive_comments, (3, 3), 10)
         trigrams_neg = ngrams_count(negative_comments, (3, 3), 10)
 
@@ -430,7 +308,7 @@ class Recommendation:
 
 
 
-        d21 = '2017-01-24'
+        d21 = '2017-01-23'
         d22 = '2017-07-23'
 
         d31 = '2017-07-23'
@@ -493,7 +371,7 @@ class Recommendation:
             # print('Total good reviews:',round(norm[0],2),'%')
             # print('Total bad reviews:',round(norm[1],2),'%')
             print('Average review score:', round(norm[0], 2), '%')
-            print('Total freight value:', round(norm[1], 2), '%')
+            print('Average freight value:', round(norm[1], 2), '%')
             print('Average delivery score:', round(norm[2], 2), '%')
 
             if revenue < 0:
@@ -532,7 +410,7 @@ class Recommendation:
             else:
                 pass
 
-        cp2 = date_dif('2017-01-24','2017-07-23')
+        cp2 = date_dif('2017-01-23','2017-07-23')
         cp3 = date_dif('2017-07-23','2017-11-26')
         cp4 = date_dif('2017-11-26','2018-07-22')
 
